#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for Matio
#---( Home Page: http://matio.sourceforge.net/
#---( Source URL: http://nchc.dl.sourceforge.net/sourceforge/matio/matio-1.3.3.tar.gz
#---( Author: R S Ananda Murthy (rsamurti@gmail.com)
#---( Date build script was last modified: Thursday, 24-April-2009.


#------------------( Set Package Name & Version )


soft='matio'
softversion='1.3.3'
packageversion='62.1'


#------------------( Check for source files )


if [ -f $soft-$softversion.tar.gz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Downloading it ..."
   wget -c http://nchc.dl.sourceforge.net/sourceforge/matio/$soft-$softversion.tar.gz
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


cd $src
./configure --prefix=/usr --enable-shared --enable-extended-sparse=yes --enable-docs=yes
make
make check
make install DESTDIR=$dest


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
cp -a README COPYING NEWS $dest/usr/doc/$soft-$softversion
cp $dest/usr/share/doc/matio/libmatio.pdf $dest/usr/doc/$soft-$softversion
rm -rf $dest/usr/share


#------------------( Copy The Build Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
     |-----handy-ruler------------------------------------------------------|
matio: matio (Library for reading and writing MATLAB files)
matio: 
matio: matio is an ISO C library (with a limited Fortran 90 interface)
matio: for reading and writing Matlab MAT files.
matio: 
matio: 
matio: 
matio: 
matio: 
matio:
matio:
EOF


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest

find . -perm 640 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 770 -exec chmod 755 {} \;
find . -perm 700 -exec chmod 755 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$package.tlz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tlz > $package.md5
zen-pkgcheck.pl $package.tlz
requiredbuilder -z $package.tlz > $package.dep
